
Common Invoke tasks

* Free software: MIT License

Features
--------

* TODO


Credits
-------

This package was created with Cookiecutter_ and the `midwatch/cc-py3-pkg`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`midwatch/cc-py3-pkg`: https://github.com/midwatch/cc-py3-pkg
